@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: bitfling.py 2741 2006-01-09 03:32:08Z sawecw $
+### $Id: bitfling.py 4228 2007-05-10 02:59:06Z djpham $
 
 """This is the BitFling client
 
@@ -453,12 +453,10 @@ class MainWindow(wx.Frame):
     def setuphelp(self):
         """Does all the nonsense to get help working"""
         import wx.html
-        # htmlhelp isn't correctly wrapper in wx package
-        from wxPython.htmlhelp import wxHtmlHelpController
         # Add the Zip filesystem
         wx.FileSystem_AddHandler(wx.ZipFSHandler())
         # Get the help working
-        self.helpcontroller=wxHtmlHelpController()
+        self.helpcontroller=wx.html.HtmlHelpController()
         self.helpcontroller.AddBook(guihelper.getresourcefile("bitpim.htb"))
         self.helpcontroller.UseConfig(self.config, "help")
 
