@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: commport.py 3466 2006-07-10 22:09:03Z djpham $
+### $Id: commport.py 4436 2007-10-30 23:10:47Z djpham $
 
 """Encapsulates the serial port device"""
 
@@ -128,7 +128,7 @@ class CommConnection:
                         continue
                     return _usbdevicewrapper(iface.openbulk(), timeout)
         self.log("Failed to find "+name+".  You may need to rescan.")
-        raise Exception("Failed to find usb device "+name)
+        raise common.CommsOpenFailure("Failed to find usb device "+name)
         
 
     def reset(self):
