@@ -5,11 +5,12 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: csv_calendar.py 4179 2007-04-03 01:07:57Z djpham $
+### $Id: csv_calendar.py 4380 2007-08-29 00:17:07Z djpham $
 
 "Deals with CSV calendar import/export stuff"
 
 # System modules
+from __future__ import with_statement
 import csv
 import datetime
 
@@ -22,6 +23,7 @@ import wx
 import bpcalendar
 import common_calendar
 import helpids
+import guihelper
 
 module_debug=False
 
@@ -75,10 +77,8 @@ class ExportCSVDialog(ExportCSVDialogParent):
         except:
             f=None
         if f is None:
-            dlg=wx.MessageDialog(self, 'Failed to open file ['+filename+']',
-                             'Export Error')
-            dlg.ShowModal()
-            dlg.Destroy()
+            guihelper.MessageDialog(self, 'Failed to open file ['+filename+']',
+                                    'Export Error')
             return
         s=['"'+x[0]+'"' for x in csv_event_template]+\
            ['"'+x[0]+'"' for x in csv_repeat_template]
@@ -456,31 +456,27 @@ class CSVImportDialog(common_calendar.PreviewDialog):
         wx.EVT_BUTTON(self, self.ID_MERGE, self.OnEndModal)
         wx.EVT_BUTTON(self, wx.ID_HELP, lambda *_: wx.GetApp().displayhelpid(helpids.ID_DLG_CALENDAR_IMPORT))
 
+    @guihelper.BusyWrapper
     def OnImport(self, evt):
-        wx.BeginBusyCursor()
-        dlg=wx.ProgressDialog('CSV Calendar Import',
-                              'Importing CSV Calendar Data, please wait ...',
-                              parent=self)
-        self.__oc.read(self.folderctrl.GetValue())
-        self.populate(self.__oc.get_display_data())
-        dlg.Destroy()
-        wx.EndBusyCursor()
+        with guihelper.WXDialogWrapper(wx.ProgressDialog('CSV Calendar Import',
+                                                         'Importing CSV Calendar Data, please wait ...',
+                                                         parent=self)) as dlg:
+            self.__oc.read(self.folderctrl.GetValue())
+            self.populate(self.__oc.get_display_data())
 
     def OnBrowseFolder(self, evt):
-        dlg=wx.FileDialog(self, "Pick a CSV Calendar File", wildcard='*.csv')
-        id=dlg.ShowModal()
-        if id==wx.ID_CANCEL:
-            dlg.Destroy()
-            return
-        self.folderctrl.SetValue(dlg.GetPath())
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, "Pick a CSV Calendar File", wildcard='*.csv'),
+                                       True) as (dlg, id):
+            if id==wx.ID_OK:
+                self.folderctrl.SetValue(dlg.GetPath())
 
     def OnFilter(self, evt):
         cat_list=self.__oc.get_category_list()
-        dlg=common_calendar.FilterDialog(self, -1, 'Filtering Parameters', cat_list)
-        if dlg.ShowModal()==wx.ID_OK:
-            self.__oc.set_filter(dlg.get())
-            self.populate(self.__oc.get_display_data())
+        with guihelper.WXDialogWrapper(common_calendar.FilterDialog(self, -1, 'Filtering Parameters', cat_list),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                self.__oc.set_filter(dlg.get())
+                self.populate(self.__oc.get_display_data())
 
     def OnEndModal(self, evt):
         self.EndModal(evt.GetId())
@@ -536,14 +532,11 @@ class CSVAutoConfCalDialog(wx.Dialog):
         main_bs.Fit(self)
 
     def OnBrowseFolder(self, evt):
-        dlg=wx.FileDialog(self, "Pick a CSV Calendar File", wildcard='*.csv')
-        id=dlg.ShowModal()
-        if id==wx.ID_CANCEL:
-            dlg.Destroy()
-            return
-        self.folderctrl.SetValue(dlg.GetPath())
-        self.__read=False
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(wx.FileDialog(self, "Pick a CSV Calendar File", wildcard='*.csv'),
+                                       True) as (dlg, retcode):
+            if retcode==wx.ID_OK:
+                self.folderctrl.SetValue(dlg.GetPath())
+                self.__read=False
 
     def OnFilter(self, evt):
         # read the calender to get the category list
@@ -551,10 +544,10 @@ class CSVAutoConfCalDialog(wx.Dialog):
             self._oc.read(self.folderctrl.GetValue())
             self.__read=True
         cat_list=self._oc.get_category_list()
-        dlg=common_calendar.AutoSyncFilterDialog(self, -1, 'Filtering Parameters', cat_list)
-        dlg.set(self._oc.get_filter())
-        if dlg.ShowModal()==wx.ID_OK:
-            self._oc.set_filter(dlg.get())
+        with guihelper.WXDialogWrapper(common_calendar.AutoSyncFilterDialog(self, -1, 'Filtering Parameters', cat_list)) as dlg:
+            dlg.set(self._oc.get_filter())
+            if dlg.ShowModal()==wx.ID_OK:
+                self._oc.set_filter(dlg.get())
 
     def GetFolder(self):
         return self.folderctrl.GetValue()
