@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: gui.py 4407 2007-09-25 20:39:48Z djpham $
+### $Id: gui.py 4579 2008-01-22 22:48:18Z djpham $
 
 """The main gui code for BitPim""" 
 
@@ -1079,10 +1079,8 @@ class MainWindow(wx.Frame):
     # deal with configuring the phone (commport)
     def OnEditSettings(self, _=None):
         if wx.IsBusy():
-            with guihelper.WXDialogWrapper(wx.MessageBox("BitPim is busy.  You can't change settings until it has finished talking to your phone.",
-                                                         "BitPim is busy.", wx.OK|wx.ICON_EXCLAMATION),
-                                           True):
-                pass
+            wx.MessageBox("BitPim is busy.  You can't change settings until it has finished talking to your phone.",
+                                                         "BitPim is busy.", wx.OK|wx.ICON_EXCLAMATION)
         else:
             # clear the ower's name for manual setting
             self.__owner_name=''
@@ -1957,7 +1955,10 @@ class WorkerThread(WorkerThreadFramework):
                 delay=results['reboot_delay']
             self.phonerebootrequest(delay)
             self.clearcomm()
-            
+        elif results.get('clearcomm', False):
+            # some model (eg Moto) needs to clear comm after certain mode
+            self.clearcomm()
+
     def writecalendar(self, data, merge):
         if __debug__: self.checkthread()
         self.setupcomm()
