@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: memo.py 4206 2007-04-27 20:19:34Z djpham $
+### $Id: memo.py 4378 2007-08-27 17:47:50Z djpham $
 
 """
 Code to handle memo/note items
@@ -47,6 +47,7 @@ The result dict key is 'memo'.
 """
 
 # standard modules
+from __future__ import with_statement
 import copy
 import datetime
 import time
@@ -539,8 +540,8 @@ class MemoWidget(wx.Panel, widgets.BitPimWidget):
         self.setdirty(False)
 
     def OnPrintDialog(self, mainwindow, config):
-        dlg=guiwidgets.MemoPrintDialog(self, mainwindow, config)
-        dlg.ShowModal()
-        dlg.Destroy()
+        with guihelper.WXDialogWrapper(guiwidgets.MemoPrintDialog(self, mainwindow, config),
+                                       True):
+            pass
     def CanPrint(self):
         return True
