@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: __init__.py 4411 2007-09-27 03:56:27Z sawecw $
+### $Id: __init__.py 4572 2008-01-15 01:58:54Z djpham $
 
 import helpids
 
@@ -87,6 +87,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                              'brand': b_lg,
                              'helpid': helpids.ID_PHONE_LGVX5300,
                              },
+              'LG-VX5400': { 'module': 'com_lgvx5400',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             'helpid': None,
+                             },
               'LG-LX5450': { 'module': 'com_lglx5450',
                              'carrier': [c_alltel],
                              'brand': b_lg,
@@ -139,6 +144,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                              'brand': b_lg,
                              'helpid': helpids.ID_PHONE_LGVX8300,
                              },
+              'LG-VX8350': { 'module': 'com_lgvx8350',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             'helpid': None,
+                             },
               'LG-VX8500': { 'module': 'com_lgvx8500',
                              'carrier': [c_vzw],
                              'brand': b_lg,
@@ -159,6 +169,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                              'brand': b_lg,
                              'helpid': helpids.ID_PHONE_LGVX8700,
                              },
+              'LG-VX8800': { 'module': 'com_lgvx8800',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             'helpid': helpids.ID_PHONE_LGVX8800,
+                             },
               'LG-VX9400': { 'module': 'com_lgvx9400',
                              'carrier': [c_vzw],
                              'brand': b_lg,
@@ -174,6 +189,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                              'brand': b_lg,
                              'helpid': helpids.ID_PHONE_LGVX9900,
                              },
+              'LG-VX10000': { 'module': 'com_lgvx10000',
+                             'carrier': [c_vzw],
+                             'brand': b_lg,
+                             'helpid': helpids.ID_PHONE_LGVX10000,
+                             },
               'LG-VI125': { 'module': 'com_lgvi125',
                             'carrier': [c_sprint],
                             'brand': b_lg,
@@ -257,6 +277,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                             'brand': b_sanyo,
                             'helpid': helpids.ID_PHONE_SANYOOTHERS,
                             },
+              'SCP-3200': { 'module': 'com_sanyo3200',
+                            'carrier': [c_sprint],
+                            'brand': b_sanyo,
+                            'helpid': helpids.ID_PHONE_SANYOOTHERS,
+                                      },
               'SCP-4900': { 'module': 'com_sanyo4900',
                             'carrier': [c_sprint],
                             'brand': b_sanyo,
@@ -277,6 +302,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                             'brand': b_sanyo,
                             'helpid': helpids.ID_PHONE_SANYOOTHERS,
                             },
+              'SCP-7050': { 'module': 'com_sanyo7050',
+                             'carrier': [c_sprint],
+                             'brand': b_sanyo,
+                             'helpid': helpids.ID_PHONE_SANYOOTHERS,
+                             },
               'SCP-7200': { 'module': 'com_sanyo7200',
                             'carrier': [c_sprint],
                             'brand': b_sanyo,
@@ -336,6 +366,21 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                                     'carrier': [c_telus],
                                     'helpid': helpids.ID_PHONE_SAMSUNGOTHERS,
                                     },
+              'SPH-A900': { 'module': 'com_samsungspha900',
+                            'carrier': [c_sprint],
+                            'brand': b_samsung,
+                            'helpid': helpids.ID_PHONE_SAMSUNGOTHERS,
+                            },
+              'SPH-M300PIM': { 'module': 'com_samsungsphm300pim',
+                               'carrier': [c_sprint],
+                               'brand': b_samsung,
+                               'helpid': helpids.ID_PHONE_SAMSUNGSPHM300,
+                               },
+              'SPH-M300MEDIA': { 'module': 'com_samsungsphm300media',
+                                 'carrier': [c_sprint],
+                                 'brand': b_samsung,
+                                 'helpid': helpids.ID_PHONE_SAMSUNGSPHM300,
+                               },
               'SPH-N200': { 'module': 'com_samsungsphn200',
                             'carrier': [c_sprint],
                             'brand': b_samsung,
@@ -356,6 +401,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                             'carrier': [c_vzw],
                             'helpid': None,
                             },
+              'SCH-A870': { 'module': 'com_samsungscha870',
+                            'brand': b_samsung,
+                            'carrier': [c_vzw],
+                            'helpid': helpids.ID_PHONE_SAMSUNGSCHA870,
+                            },
               'SCH-A950': { 'module': 'com_samsungscha950',
                             'brand': b_samsung,
                             'carrier': [c_vzw],
@@ -366,6 +416,16 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                             'carrier': [c_vzw],
                             'helpid': helpids.ID_PHONE_SAMSUNGSCHA930,
                             },
+              'SCH-U470': { 'module': 'com_samsungschu470',
+                            'brand': b_samsung,
+                            'carrier': [c_vzw],
+                            'helpid': helpids.ID_PHONE_SAMSUNGSCHU470,
+                            },
+              'SCH-U740': { 'module': 'com_samsungschu740',
+                            'brand': b_samsung,
+                            'carrier': [c_vzw],
+                            'helpid': helpids.ID_PHONE_SAMSUNGSCHU740,
+                            },
               'SK6100' : { 'module': 'com_sk6100',
                            'brand': b_sk,
                            'carrier': [c_pelephone],
@@ -406,6 +466,26 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                         'carrier': [c_vzw],
                         'helpid': helpids.ID_PHONE_MOTOV3CM,
                         },
+              'V3m': { 'module': 'com_motov3m',
+                        'brand': b_moto,
+                        'carrier': [c_vzw],
+                        'helpid': helpids.ID_PHONE_MOTOV3M,
+                        },
+              'V3mM': { 'module': 'com_motov3mm',
+                        'brand': b_moto,
+                        'carrier': [c_vzw],
+                        'helpid': helpids.ID_PHONE_MOTOV3MM,
+                        },
+              'V325': { 'module': 'com_motov325',
+                        'brand': b_moto,
+                        'carrier': [c_vzw],
+                        'helpid': helpids.ID_PHONE_MOTOV325,
+                        },
+              'V325M': { 'module': 'com_motov325m',
+                         'brand': b_moto,
+                         'carrier': [c_vzw],
+                         'helpid': helpids.ID_PHONE_MOTOV325M,
+                        },
               'E815': { 'module': 'com_motoe815',
                         'brand': b_moto,
                         'carrier': [c_vzw],
@@ -416,6 +496,11 @@ _phonedata= { 'LG-AX8600': { 'module': 'com_lgax8600',
                          'carrier': [c_vzw],
                         'helpid': helpids.ID_PHONE_MOTOE815M,
                          },
+              'K1m': { 'module': 'com_motok1m',
+                       'brand': b_moto,
+                       'carrier': [c_vzw],
+                       'helpid': helpids.ID_PHONE_MOTOK1M,
+                       },
               'Other CDMA phone': { 'module': 'com_othercdma',
                                     'carrier': [c_other],
                                     'brand': b_other,
@@ -428,11 +513,6 @@ if __debug__:
                                                'brand': b_audiovox,
                                                'helpid': None,
                                                },
-                        'SCH-A870': { 'module': 'com_samsungscha870',
-                                      'brand': b_samsung,
-                                      'carrier': [c_vzw],
-                                      'helpid': None,
-                                      },
                         'SPH-A790': { 'module': 'com_samsungspha790',
                                       'brand': b_samsung,
                                       'carrier': [c_sprint],
@@ -443,16 +523,6 @@ if __debug__:
                                       'carrier': [c_tmobileusa],
                                       'helpid': None,
                                       },
-                        'SPH-A900': { 'module': 'com_samsungspha900',
-                                      'carrier': [c_sprint],
-                                      'brand': b_samsung,
-                                      'helpid': helpids.ID_PHONE_SAMSUNGOTHERS,
-                                      },
-                        'SCP-3200': { 'module': 'com_sanyo3200',
-                                      'carrier': [c_sprint],
-                                      'brand': b_sanyo,
-                                      'helpid': helpids.ID_PHONE_SANYOOTHERS,
-                                      },
                         'SCP-8400': { 'module': 'com_sanyo8400',
                                       'carrier': [c_sprint],
                                       'brand': b_sanyo,
