@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_brew.py 4359 2007-08-17 03:31:52Z djpham $
+### $Id: com_brew.py 4563 2008-01-11 21:49:45Z djpham $
 
 """Implements the "Brew" filesystem protocol"""
 
@@ -420,6 +420,8 @@ class RealBrewProtocol:
         req.entrynumber=0
         try:
             res=self.sendbrewcommand(req,p_brew.listfileresponse)
+        except BrewNoMoreEntriesException:
+            pass
         except (BrewBadPathnameException, BrewNoSuchDirectoryException,
                 BrewAccessDeniedException):
             return False
@@ -429,6 +431,27 @@ class RealBrewProtocol:
             return False
         return True
 
+    def basename(self, path):
+        # return the basename of the path, does not check on whether the path
+        # exists.
+        _dirs=[x for x in path.split('/') if x]
+        if _dirs:
+            return _dirs[-1]
+        return ''
+
+    def dirname(self, filename):
+        # return the dir name of the filename, does not check on whether
+        # the file exists.
+        _dirs=[x for x in filename.split('/') if x]
+        if len(_dirs)<2:
+            # either / or /name
+            return '/'
+        return '/'.join(_dirs[:-1])
+
+    def join(self, *args):
+        # join the dir/file components and return the full path name
+        return '/'.join([x.strip('/') for x in args])
+
     def listsubdirs(self, dir='', recurse=0):
         results={}
         self.log("Listing subdirs in dir: '"+dir+"'")
@@ -647,6 +670,11 @@ class RealBrewProtocol:
     def _setmodebrew(self):
         req=p_brew.memoryconfigrequest()
         respc=p_brew.memoryconfigresponse
+        try:
+            self.sendbrewcommand(req, respc, callsetmode=False)
+            return True
+        except modeignoreerrortypes:
+            pass
         
         for baud in 0, 38400,115200:
             if baud:
@@ -810,11 +838,12 @@ class RealBrewProtocol:
             raise
         return res
 
-class RealBrewProtocol2:
+class RealBrewProtocol2(RealBrewProtocol):
     """Talk to a phone using the 'brew' protocol
     This class uses the new filesystem commands which are supported
     by newer qualcomm chipsets used in phones like the LG vx8100
     """
+
     def exists(self, name):
         try:
             self.statfile(name)
@@ -1057,58 +1086,79 @@ class RealBrewProtocol2:
             results['date']=(0, '')
         return results
 
-class BrewProtocol(RealBrewProtocol):
-    """This is just a wrapper class that allows the manipulation between
-    RealBrewProtocol and DebugBrewProtocol classes.
-    """
-    def __init__(self):
-        RealBrewProtocol.__init__(self)
-        # if the env var PHONE_FS is set, we're debugging!
-        phone_path=os.environ.get('PHONE_FS', None)
-        if __debug__ and phone_path:
-            print 'Debug Phone File System:',phone_path
-            # we probably need to do this only once for the whole class,
-            # but what the heck!
-            DebugBrewProtocol._fs_path=os.path.normpath(phone_path)
-            self._update_base_class(self.__class__)
-            # define BREW_FILE_SYSTEM=2 in protocol class to enable 
-            # new brew filesystem support. Debug mode only
-##        elif __debug__ and getattr(self, "protocolclass", 0) and \
-##                getattr(self.protocolclass, "BREW_FILE_SYSTEM", 0) == 2:
-##            print '_set_new_brew', self.protocolclass
-##            self._set_new_brew(self.__class__)
+phone_path=os.environ.get('PHONE_FS', None)
+if __debug__ and phone_path:
+    DebugBrewProtocol._fs_path=os.path.normpath(phone_path)
+    BrewProtocol=DebugBrewProtocol
+else:
+    BrewProtocol=RealBrewProtocol
+del phone_path
 
-    def _update_base_class(self, klass):
-        # update the RealBrewProtocol class to DebugBrewProtocol one.
-        _bases=[]
-        found=False
-        for e in klass.__bases__:
-            if e==RealBrewProtocol:
-                _bases.append(DebugBrewProtocol)
-                found=True
-            else:
-                _bases.append(e)
-        if found:
-            klass.__bases__=tuple(_bases)
-        else:
-            for e in _bases:
-                self._update_base_class(e)
-
-    def _set_new_brew(self, klass):
-        # update the class hierachy to include RealBrewProtocol2 so that 
-        # it's functions override RealBrewProtocol's ones.
-        _bases=[]
-        found=False
-        for e in klass.__bases__:
-            if e==RealBrewProtocol:
-                _bases.append(RealBrewProtocol2)
-                found=True
-            _bases.append(e)
-        if found:
-            klass.__bases__=tuple(_bases)
-        else:
-            for e in _bases:
-                self._set_new_brew(e)
+##class BrewProtocol(RealBrewProtocol):
+##    """This is just a wrapper class that allows the manipulation between
+##    RealBrewProtocol and DebugBrewProtocol classes.
+##    """
+##    def __init__(self):
+##        RealBrewProtocol.__init__(self)
+##        # if the env var PHONE_FS is set, we're debugging!
+##        phone_path=os.environ.get('PHONE_FS', None)
+##        if __debug__ and phone_path:
+##            print 'Debug Phone File System:',phone_path
+##            # we probably need to do this only once for the whole class,
+##            # but what the heck!
+##            DebugBrewProtocol._fs_path=os.path.normpath(phone_path)
+##            for _attr in DebugBrewProtocol.exportedfuncs:
+##                setattr(self, _attr, getattr(DebugBrewProtocol, _attr))
+##            self._update_base_class(self.__class__)
+##            for _attr in DebugBrewProtocol.exportedfuncs:
+##                setattr(BrewProtocol, _attr, getattr(DebugBrewProtocol, _attr))
+##            # define BREW_FILE_SYSTEM=2 in protocol class to enable 
+##            # new brew filesystem support. Debug mode only
+####        elif __debug__ and getattr(self, "protocolclass", 0) and \
+####                getattr(self.protocolclass, "BREW_FILE_SYSTEM", 0) == 2:
+####            print '_set_new_brew', self.protocolclass
+####            self._set_new_brew(self.__class__)
+##
+##    def __call__(self, *args, **kwargs):
+##        return self._klass.__call__(self, *args, **kwargs)
+##    def _printclass(self, klass):
+##        if klass.__bases__:
+##            for _c in klass.__bases__:
+##                self._printclass(_c)
+##        else:
+##            print klass
+##            
+##    def _update_base_class(self, klass):
+##        # update the RealBrewProtocol class to DebugBrewProtocol one.
+##        _bases=[]
+##        found=False
+##        for e in klass.__bases__:
+##            if e==RealBrewProtocol or e==RealBrewProtocol2:
+##                _bases.append(DebugBrewProtocol)
+##                found=True
+##            else:
+##                _bases.append(e)
+##        if found:
+##            klass.__bases__=tuple(_bases)
+##        else:
+##            for e in _bases:
+##                self._update_base_class(e)
+##
+##    def _set_new_brew(self, klass):
+##        # update the class hierachy to include RealBrewProtocol2 so that 
+##        # it's functions override RealBrewProtocol's ones.
+##        _bases=[]
+##        found=False
+##        for e in klass.__bases__:
+##            if e==RealBrewProtocol:
+##                _bases.append(RealBrewProtocol2)
+##                found=True
+##            _bases.append(e)
+##        if found:
+##            klass.__bases__=tuple(_bases)
+##        else:
+##            for e in _bases:
+##                self._set_new_brew(e)
 
 def formatpacketerrorlog(str, origdata, data, klass):
     # copied from guiwidgets.LogWindow.logdata
