@@ -6,7 +6,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx3200.py 3298 2006-05-28 03:10:52Z skyjunky $
+### $Id: com_lgvx3200.py 3918 2007-01-19 05:15:12Z djpham $
 
 """Communicate with the LG VX3200 cell phone
 
@@ -23,6 +23,7 @@ import re
 # my modules
 import common
 import copy
+import helpids
 import p_lgvx3200
 import com_lgvx4400
 import com_brew
@@ -39,6 +40,7 @@ class Phone(com_lgvx4400.Phone):
     "Talk to the LG VX3200 cell phone"
 
     desc="LG-VX3200"
+    helpid=helpids.ID_PHONE_LGVX3200
 
     wallpaperindexfilename="download/dloadindex/brewImageIndex.map"
     ringerindexfilename="download/dloadindex/brewRingerIndex.map"
