@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_lgvx4400.py 3918 2007-01-19 05:15:12Z djpham $
+### $Id: com_lgvx4400.py 4395 2007-09-11 21:11:45Z djpham $
 
 """Communicate with the LG VX4400 cell phone"""
 
@@ -93,20 +93,14 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
         # use a hash of ESN and other stuff (being paranoid)
         self.log("Retrieving fundamental phone information")
         self.log("Phone serial number")
-        results['uniqueserial']=sha.new(self.getfilecontents("nvm/$SYS.ESN")).hexdigest()
-        # now read groups
-        self.log("Reading group information")
-        buf=prototypes.buffer(self.getfilecontents("pim/pbgroup.dat"))
-        g=self.protocolclass.pbgroups()
-        g.readfrombuffer(buf, logtitle="Groups read")
-        groups={}
-        for i in range(len(g.groups)):
-            if len(g.groups[i].name): # sometimes have zero length names
-                groups[i]={ 'icon': g.groups[i].icon, 'name': g.groups[i].name }
-        results['groups']=groups
+        results['uniqueserial']=sha.new(self.get_esn()).hexdigest()
+
+        self.getgroups(results)
         self.getwallpaperindices(results)
         self.getringtoneindices(results)
+
         self.log("Fundamentals retrieved")
+
         return results
 
     def savesms(self, result, merge):
@@ -416,6 +410,18 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
         print "returning keys",result.keys()
         return pbook
 
+    def getgroups(self, results):
+        self.log("Reading group information")
+        buf=prototypes.buffer(self.getfilecontents("pim/pbgroup.dat"))
+        g=self.protocolclass.pbgroups()
+        g.readfrombuffer(buf, logtitle="Groups read")
+        groups={}
+        for i in range(len(g.groups)):
+            if len(g.groups[i].name): # sometimes have zero length names
+                groups[i]={ 'icon': g.groups[i].icon, 'name': g.groups[i].name }
+        results['groups']=groups
+        return groups
+
     def savegroups(self, data):
         groups=data['groups']
         keys=groups.keys()
@@ -892,8 +898,8 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
             s=res.get(self.esn_file_key, None)
             if s:
                 res['esn']=self.get_esn(s)
-
-    def detectphone(coms, likely_ports, res, _module, _log):
+    @classmethod
+    def detectphone(_, coms, likely_ports, res, _module, _log):
         if not likely_ports:
             # cannot detect any likely ports
             return None
@@ -920,8 +926,6 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
                 if __debug__:
                     raise
     
-    detectphone=staticmethod(detectphone)
-
     # Calendar stuff------------------------------------------------------------
     def getcalendar(self,result):
         # Read exceptions file first
@@ -1191,11 +1195,11 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
         self._set_repeat_event(event, entry, exceptions)
             
     def set_cal(self, sch_file, cal_dict, ringtone_index, voice_files):
-        sch_file.numactiveitems=len(cal_dict)
         exceptions={}
         _pos=2
         _packet_size=None
 ##        _today=datetime.date.today().timetuple()[:5]
+        _entry_cnt=0
         for k, e in cal_dict.items():
 ##            # only send either repeat events or present&future single events
 ##            if e.repeat or (e.start>=_today):
@@ -1207,6 +1211,10 @@ class Phone(com_phone.Phone,com_brew.BrewProtocol,com_lg.LGPhonebook,com_lg.LGIn
             if not _packet_size:
                 _packet_size=event.packetsize()
             _pos+=_packet_size
+            _entry_cnt+=1
+            if _entry_cnt>=self.protocolclass.NUMCALENDARENTRIES:
+                break
+        sch_file.numactiveitems=_entry_cnt
         return exceptions
 
     # Text Memo stuff-----------------------------------------------------------
