@@ -6,6 +6,7 @@
 ###
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
+### $Id: com_lgvx8550.py 4540 2008-01-04 03:40:48Z djpham $
 
 
 """
@@ -15,11 +16,16 @@ Communicate with the LG VX8550 cell phone.
 # BitPim modules
 import common
 import com_brew
+import bpcalendar
 import prototypes
 import com_lgvx8700
 import com_lgvx8500
 import p_lgvx8550
+import p_brew
 import helpids
+import copy
+import time
+import os.path
 
 #-------------------------------------------------------------------------------
 parentphone=com_lgvx8700.Phone
@@ -31,6 +37,8 @@ class Phone(parentphone):
 
     my_model='VX8550'
 
+    calendarringerlocation='sch/toolsRinger.dat'
+
     def setDMversion(self):
         self._DMv5=True
 
@@ -41,48 +49,33 @@ class Phone(parentphone):
     #  - getringtoneindices  - LGUncountedIndexedMedia
     #  - DM Version          - 5
 
+    def _get_path_index(self, index_file):
+        buf = prototypes.buffer(self.getfilecontents(index_file))
+        _path_file=self.protocolclass.PathIndexFile()
+        _path_file.readfrombuffer(buf, logtitle="Read path index: " + index_file)
+        return _path_file
+
     def savephonebook (self, data):
         "Saves out the phonebook"
         self.savegroups (data)
 
-        # the VX-8550 does not appear to support the LG phonebook protocol so /pim files are used
-        pb_entrybuf = prototypes.buffer(self.getfilecontents(self.protocolclass.pb_file_name))
-        pb_entries = self.protocolclass.pbfile()
-        self.progress (1, 2, "Parsing phonebook")
-        pb_entries.readfrombuffer(pb_entrybuf, logtitle="Read phonebook entries")
-
-        pb_numberbuf = prototypes.buffer(self.getfilecontents(self.protocolclass.pn_file_name))
-        pb_numbers = self.protocolclass.pnfile()
-        self.progress (2, 2, "Parsing phone numbers")
-        pb_numbers.readfrombuffer(pb_numberbuf, logtitle="Read phonebook numbers")
-
-        # read the existing phonebook
-        entry_num = 0
-        existingpbook={}
-        for pb_entry in pb_entries.items:
-            if pb_entry.entry_number0 == 0xffff:
-                break
-
-            entry_group = []
-            for item in pb_entry.entrygroup:
-                entry_group.append(item.value)
-
-            entry = { 'name': pb_entry.name, 'type': pb_entry.entry_type, 'entrygroup': entry_group }
-            self.log ("Parsed entry "+`entry_num`+" - "+entry['name'])
-            existingpbook[entry_num] = entry
-
-            entry_num += 1
+        ring_pathf=self.protocolclass.PathIndexFile()
+        picid_pathf=self.protocolclass.PathIndexFile()
 
         # the pbentry.dat will will be overwritten so there is no need to delete entries
         pbook = data['phonebook']
         keys = pbook.keys ()
         keys.sort ()
 
+        _rt_index=data.get('ringtone-index', {})
+        _wp_index=data.get('wallpaper-index', {})
+
         entry_num = 0
         new_pn_entries = {}
         newspeeds = {}
+        pb_entries = self.protocolclass.pbfile()
         for i in keys:
-            pb_entries.items[entry_num] = self.make_entry (new_pn_entries, entry_num, pbook[i], existingpbook, data)
+            pb_entries.items.append(self.make_entry (new_pn_entries, entry_num, pbook[i], data, ring_pathf, _rt_index, picid_pathf, _wp_index))
 
             # already know the new index so speed dials can be redone here
             if len (data['speeddials']):
@@ -129,10 +122,18 @@ class Phone(parentphone):
         # finally, write out the new phone number database
         self.writefile (self.protocolclass.pn_file_name, new_pb_numbersbuf.getvalue())
 
+        # write ringtone index
+        _buf=prototypes.buffer()
+        ring_pathf.writetobuffer(_buf, logtitle='Writing Ringtone ID')
+        self.writefile(self.protocolclass.RTPathIndexFile, _buf.getvalue())
 
+        # write wallpaer index
+        _buf=prototypes.buffer()
+        picid_pathf.writetobuffer(_buf, logtitle='Writing Wallpaper ID')
+        self.writefile(self.protocolclass.WPPathIndexFile, _buf.getvalue())
+    
         # might need to update the ICE index as well
 
-
         # update speed dials
         req=self.protocolclass.speeddials()
         for i in range(self.protocolclass.NUMSPEEDDIALS):
@@ -143,7 +144,7 @@ class Phone(parentphone):
             req.speeddials.append(sd)
         buffer=prototypes.buffer()
         req.writetobuffer(buffer, logtitle="New speed dials")
-                    
+
         # We check the existing speed dial file as changes require a reboot
         self.log("Checking existing speed dials")
         if buffer.getvalue()!=self.getfilecontents(self.protocolclass.speed_file_name):
@@ -156,46 +157,32 @@ class Phone(parentphone):
 
         return data
 
-    def get_existing_assoc (self, pb_entry, existingpbook, assoc):
-        for existing_entry in existingpbook:
-            if existingpbook[existing_entry]['name'] == pb_entry['name']:
-                return existingpbook[existing_entry][assoc]
-
-        # no existing association
-        if assoc == 'type':
-            return 0x000707D7 # default type
-        elif assoc == 'entrygroup':
-            # arbitrary value -- the value does not need to be unique
-            return [0x0006, 0x0010, 0x0010, 0x0010]
-
-    def make_pn_entry (self, phone_number, number_type, pn_id, pe_id, pe_entry_type, pe_entrygroup):
+    def make_pn_entry (self, phone_number, number_type, pn_id, pbpn_id, pe_id, date):
         """ Create a non-blank pnfileentry frome a phone number string """
         if len(phone_number) == 0:
             raise
         
         new_entry = self.protocolclass.pnfileentry()
 
-        new_entry.entry_type = pe_entry_type
-        for item in pe_entrygroup:
-            new_entry.entrygroup.append (item)
+        for i in range(0, 6):
+            new_entry.mod_date.append(date[i])
         new_entry.pn_id = pn_id
         new_entry.pe_id = pe_id
         new_entry.phone_number = phone_number
         new_entry.type = number_type
+        new_entry.pn_order = pbpn_id
 
         return new_entry
 
-    def make_entry (self, pn_entries, entry_num, pb_entry, existingpbook, data):
+    def make_entry (self, pn_entries, entry_num, pb_entry, data, ring_pathf, rt_index, picid_pathf, wp_index):
         """ Create a pbfileentry from a bitpim phonebook entry """
         new_entry = self.protocolclass.pbfileentry()
 
-        pe_entry_type = self.get_existing_assoc (pb_entry, existingpbook, 'type')
-        pe_entrygroup = self.get_existing_assoc (pb_entry, existingpbook, 'entrygroup')
+        # set modification date to current date
+        date = time.localtime()
+        for i in range(0, 6):
+            new_entry.mod_date.append(date[i])
 
-        for item in pe_entrygroup:
-            new_entry.entrygroup.append (item)
-
-        new_entry.entry_type = pe_entry_type
         new_entry.entry_number0 = entry_num
         new_entry.entry_number1 = entry_num + 1
 
@@ -214,14 +201,28 @@ class Phone(parentphone):
                         break
 
                     try:
-                         pn_entries[new_pn_id] = self.make_pn_entry (pb_entry[key][i], pb_entry['numbertypes'][i], new_pn_id, entry_num, pe_entry_type, pe_entrygroup)
+                         pn_entries[new_pn_id] = self.make_pn_entry (pb_entry[key][i], pb_entry['numbertypes'][i], new_pn_id, i, entry_num, date)
                          l.append (new_pn_id)
                     except:
                          l.append (0xffff)
             elif key == 'ringtone':
                 new_entry.ringtone = self._findmediainindex(data['ringtone-index'], pb_entry['ringtone'], pb_entry['name'], 'ringtone')
+                try:
+                    _filename = rt_index[new_entry.ringtone]['filename']
+                    ring_pathf.items.append(self.protocolclass.PathIndexEntry(pathname=_filename))
+                    new_entry.ringtone = 0x64
+                    self.log ('Contact ringtone: ' + _filename)
+                except:
+                    ring_pathf.items.append(self.protocolclass.PathIndexEntry())
             elif key == 'wallpaper':
                 new_entry.wallpaper = self._findmediainindex(data['wallpaper-index'], pb_entry['wallpaper'], pb_entry['name'], 'wallpaper')
+                try:
+                    _filename = wp_index[new_entry.wallpaper]['filename']
+                    picid_pathf.items.append(self.protocolclass.PathIndexEntry(pathname=_filename))
+                    new_entry.ringtone = 0x64
+                    self.log ('Contact wallpaper: ' + _filename)
+                except:
+                    picid_pathf.items.append(self.protocolclass.PathIndexEntry())
             elif key in new_entry.getfields():
                 setattr (new_entry, key, pb_entry[key])
 
@@ -260,16 +261,25 @@ class Phone(parentphone):
         pb_numbers = self.protocolclass.pnfile()
         pb_numbers.readfrombuffer(pb_numberbuf, logtitle="Read phonebook numbers")
 
+        self.log("Reading Ringtone IDs")
+        ring_pathf=self._get_path_index(self.protocolclass.RTPathIndexFile)
+
+        self.log("Reading Picture IDs")
+        picid_pathf=self._get_path_index(self.protocolclass.WPPathIndexFile)
+
         numentries = 0
 
         pbook={}
         for pb_entry in pb_entries.items:
-            if pb_entry.entry_number0 == 0xffff:
-                break
+            # skip blank entries
+            if pb_entry.entry_number1 == 0xffffffffL:
+                continue
 
             try:
                 self.log("Parse entry "+`numentries`+" - " + pb_entry.name)
-                entry=self.extractphonebookentry(pb_entry, pb_numbers, speeds, result)
+                entry=self.extractphonebookentry(pb_entry, pb_numbers, speeds, result,
+                                                 os.path.basename(ring_pathf.items[numentries].pathname),
+                                                 os.path.basename(picid_pathf.items[numentries].pathname))
 
                 pbook[numentries]=entry
 
@@ -295,7 +305,7 @@ class Phone(parentphone):
         print "returning keys",result.keys()
         return pbook
 
-    def extractphonebookentry(self, entry, numbers, speeds, fundamentals):
+    def extractphonebookentry(self, entry, numbers, speeds, fundamentals, ring_name, picid_name):
         """Return a phonebook entry in BitPim format.  This is called from getphonebook."""
         res={}
         # serials
@@ -328,7 +338,10 @@ class Phone(parentphone):
         # wallpapers
         if entry.wallpaper!=self.protocolclass.NOWALLPAPER:
             try:
-                paper=fundamentals['wallpaper-index'][entry.wallpaper]['name']
+                if entry.wallpaper == 0x64:
+                    paper = picid_name
+                else:
+                    paper = fundamentals['wallpaper-index'][entry.wallpaper]['name']
                 res['wallpapers']=[ {'wallpaper': paper, 'use': 'call'} ]                
             except:
                 print "can't find wallpaper for index",entry.wallpaper
@@ -338,7 +351,11 @@ class Phone(parentphone):
         res['ringtones']=[]
         if entry.ringtone != self.protocolclass.NORINGTONE:
             try:
-                tone=fundamentals['ringtone-index'][entry.ringtone]['name']
+                if entry.ringtone == 0x64:
+                    tone = ring_name
+                else:
+                    tone=fundamentals['ringtone-index'][entry.ringtone]['name']
+                self.log('Tone is ' + tone)
                 res['ringtones'].append({'ringtone': tone, 'use': 'call'})
             except:
                 print "can't find ringtone for index",entry.ringtone
@@ -369,6 +386,145 @@ class Phone(parentphone):
                     res['numbers'][i]['speeddial']=_sd_dict[type]
         return res
 
+    def getcalendar(self,result):
+        res={}
+        # Read exceptions file first
+        exceptions = self.getexceptions()
+
+        try:
+            buf = prototypes.buffer(self.getfilecontents(self.calendarringerlocation))
+            ringersf = self.protocolclass.scheduleringerfile()
+            ringersf.readfrombuffer (buf)
+        except:
+            self.log ("unable to read schedule ringer path file")
+        
+        # Now read schedule
+        try:
+            buf=prototypes.buffer(self.getfilecontents(self.calendarlocation))
+            if len(buf.getdata())<3:
+                # file is empty, and hence same as non-existent
+                raise com_brew.BrewNoSuchFileException()
+            sc=self.protocolclass.schedulefile()
+            sc.readfrombuffer(buf, logtitle="Calendar")
+            for event in sc.events:
+                # the vx8100 has a bad entry when the calender is empty
+                # stop processing the calender when we hit this record
+                if event.pos==0: #invalid entry
+                    continue
+                entry=bpcalendar.CalendarEntry()
+                try: # delete events are still in the calender file but have garbage dates
+                    self.getcalendarcommon(entry, event)
+                except ValueError:
+                    continue
+                try:
+                    if (event.ringtone >= 100):   # MIC Ringer is downloaded to phone or microSD
+                        entry.ringtone = common.basename(ringersf.ringerpaths[event.ringtone-100].path)
+                    else:                         # MIC Ringer is built-in
+                        entry.ringtone=self.builtinringtones[event.ringtone]
+                except:
+                    self.log ("Setting default ringer for event\n")
+                    # hack, not having a phone makes it hard to figure out the best approach
+                    if entry.alarm==None:
+                        entry.ringtone='No Ring'
+                    else:
+                        entry.ringtone='Loud Beeps'
+                # check for exceptions and remove them
+                if event.repeat[3] and exceptions.has_key(event.pos):
+                    for year, month, day in exceptions[event.pos]:
+                        entry.suppress_repeat_entry(year, month, day)
+                res[entry.id]=entry
+
+            assert sc.numactiveitems==len(res)
+        except com_brew.BrewNoSuchFileException:
+            pass # do nothing if file doesn't exist
+        result['calendar']=res
+        return result
+
+    def _scheduleextras(self, data, fwversion):
+        data.serial_number = '000000ca-00000000-00000000-' + fwversion
+        data.unknown3 = 0x01fb
+        
+    def savecalendar(self, dict, merge):
+        # ::TODO::
+        # what will be written to the files
+        eventsf     = self.protocolclass.schedulefile()
+        exceptionsf = self.protocolclass.scheduleexceptionfile()
+        ringersf    = self.protocolclass.scheduleringerfile()
+        # what are we working with
+        cal=dict['calendar']
+        newcal={}
+        #sort into start order, makes it possible to see if the calendar has changed
+        keys=[(x.start, k) for k,x in cal.items()]
+        keys.sort()
+        # apply limiter
+        keys=keys[:self.protocolclass.NUMCALENDARENTRIES]
+        # number of entries
+        eventsf.numactiveitems=len(keys)
+        ringersf.numringers = 0
+        pos = 0
+        # get phone firmware version for serial number
+        try:
+            req = p_brew.firmwarerequest()
+            res = self.sendbrewcommand(req, self.protocolclass.firmwareresponse)
+            _fwversion = res.firmware
+        except:
+            _fwversion = '00000000'
+
+        # play with each entry
+        for (_,k) in keys:
+            # entry is what we will return to user
+            entry=cal[k]
+            data=self.protocolclass.scheduleevent()
+            # using the packetsize() method here will fill the LIST with default entries
+            data.pos = pos * data.packet_size + 2
+            self._schedulecommon(entry, data)
+            alarm_set=self.setalarm(entry, data)
+            if alarm_set:
+                if entry.ringtone=="No Ring" and not entry.vibrate:
+                    alarm_name="Low Beep Once"
+                else:
+                    alarm_name=entry.ringtone
+            else: # set alarm to "No Ring" gets rid of alarm icon on phone
+                alarm_name="No Ring"
+            for i in dict['ringtone-index']:
+                self.log ('ringtone ' + str(i) + ': ' + dict['ringtone-index'][i]['name'] + ' alarm-name = ' + alarm_name)  
+                if dict['ringtone-index'][i]['name']==alarm_name:
+                    if dict['ringtone-index'][i].get('filename', None):
+                        data.ringtone = 100 + ringersf.numringers
+                        ringersf.ringerpaths.append(dict['ringtone-index'][i]['filename'])
+                        ringersf.numringers = ringersf.numringers + 1
+                    else:
+                        # builtin ringer
+                        data.ringtone=i      # Set to proper index
+                    break
+            # check for exceptions and add them to the exceptions list
+            self._scheduleexceptions(entry, data, exceptionsf)
+            self._scheduleextras(data, _fwversion)
+            # put entry in nice shiny new dict we are building
+            entry=copy.copy(entry)
+            newcal[data.pos]=entry
+            eventsf.events.append(data)            
+            pos = pos + 1
+
+        buf=prototypes.buffer()
+        eventsf.writetobuffer(buf, logtitle="New Calendar")
+        self.writefile(self.calendarlocation, buf.getvalue())
+        self.log("Your phone has to be rebooted due to the calendar changing")
+        dict["rebootphone"]=True
+
+        buf=prototypes.buffer()
+        exceptionsf.writetobuffer(buf, logtitle="Writing calendar exceptions")
+        self.writefile(self.calendarexceptionlocation, buf.getvalue())
+
+        buf = prototypes.buffer()
+        ringersf.writetobuffer(buf, logtitle="Writing calendar ringers")
+        self.writefile(self.calendarringerlocation, buf.getvalue())
+
+        # fix passed in dict
+        dict['calendar']=newcal
+
+        return dict
+
 #-------------------------------------------------------------------------------
 parentprofile=com_lgvx8500.Profile
 class Profile(parentprofile):
