@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_motov710.py 4365 2007-08-17 21:11:59Z djpham $
+### $Id: com_motov710.py 4533 2007-12-28 05:54:09Z djpham $
 
 """Communicate with Motorola phones using AT commands"""
 # system modules
@@ -115,7 +115,6 @@ class Phone(com_moto_cdma.Phone):
             self.protocolclass.RT_INDEX_FILE))
         _idx_file=self.protocolclass.ringtone_index_file()
         _idx_file.readfrombuffer(_buf, logtitle='Read ringtone index file')
-        _path_len=len(self.protocolclass.RT_PATH)+1
         for _entry in _idx_file.items:
             _filename=self.decode_utf16(_entry.name)
             res[_entry.index]={ 'name': common.basename(_filename),
@@ -129,10 +128,12 @@ class Phone(com_moto_cdma.Phone):
         _files=self.listfiles(self.protocolclass.WP_PATH).keys()
         _files.sort()
         _wp_path_len=len(self.protocolclass.WP_PATH)+1
-        for _index,_name in enumerate(_files):
-            res[_index]={ 'name': common.basename(_name),
-                          'filename': _name,
-                          'origin': 'images' }
+        for _index,_filename in enumerate(_files):
+            _name=common.basename(_filename)
+            if _name not in self.protocolclass.WP_EXCLUDED_FILES:
+                res[_index]={ 'name': _name,
+                              'filename': _filename,
+                              'origin': 'images' }
         return res
 
     # phonebook stuff-----------------------------------------------------------
@@ -191,9 +192,9 @@ class Phone(com_moto_cdma.Phone):
         """
         # extract the number, email, or mailing list
         _num_type=entry.number_type
-        if _num_type<self.protocolclass.NUMBER_TYPE_EMAIL:
+        if _num_type in self.protocolclass.NUMBER_TYPE:
             self._populate_pb_number(pb_entry, entry, fundamentals)
-        elif _num_type==self.protocolclass.NUMBER_TYPE_EMAIL:
+        elif _num_type in self.protocolclass.EMAIL_TYPE:
             self._populate_pb_email(pb_entry, entry, fundamentals)
         # this is a mail list, which is not currently supported
 ##        else:
@@ -261,7 +262,11 @@ class Phone(com_moto_cdma.Phone):
 
     def _get_ringtone_code(self, entry, fundamentals):
         """Return the ringtone code of this entry"""
-        _ringtone_name=entry.get('ringtone', None)
+        # check the global ringtone setting first
+        _ringtone_name=fundamentals.get('phoneringtone', None)
+        if not _ringtone_name:
+            _ringtone_name=entry.get('ringtone', None)
+        # and then individual number ringtone
         if not _ringtone_name:
             return 255
         for _key,_entry in fundamentals.get('ringtone-index', {}).items():
@@ -271,7 +276,11 @@ class Phone(com_moto_cdma.Phone):
 
     def _get_wallpaper_name(self, entry, fundamentals):
         """Return the full path name for the wallpaper"""
-        _wp_name=entry.get('wallpaper', None)
+        # Check for global wallpaper setting first
+        _wp_name=fundamentals.get('phonewallpaper', None)
+        # then check for individual number ringtone
+        if not _wp_name:
+            _wp_name=entry.get('wallpaper', None)
         if not _wp_name:
             return ''
         return '/a/'+self.protocolclass.WP_PATH+'/'+_wp_name
@@ -303,6 +312,7 @@ class Phone(com_moto_cdma.Phone):
     def _write_pb_entry_numbers(self, entry, req, fundamentals):
         """Write all the numbers to the phone"""
         req.local_type=self.protocolclass.LOCAL_TYPE_LOCAL
+        _cell1=False
         for _entry in entry.get('numbers', []):
             req.index=_entry['speeddial']
             if req.index>self.protocolclass.PB_TOTAL_ENTRIES:
@@ -311,6 +321,12 @@ class Phone(com_moto_cdma.Phone):
             req.number=_entry['number']
             req.number_type=self.protocolclass.NUMBER_TYPE_CODE.get(
                 _entry['type'], self.protocolclass.NUMBER_TYPE_WORK)
+            if req.number_type==self.protocolclass.NUMBER_TYPE_MOBILE:
+                if _cell1:
+                    # this is cell2
+                    req.number_type=self.protocolclass.NUMBER_TYPE_MOBILE2
+                else:
+                    _cell1=True
             self._set_pb_entry_misc(req, _entry, fundamentals)
             self._del_pb_entry(req.index)
             self.sendATcommand(req, None)
@@ -319,11 +335,17 @@ class Phone(com_moto_cdma.Phone):
         """Write all emails to the phone"""
         req.number_type=self.protocolclass.NUMBER_TYPE_EMAIL
         req.local_type=self.protocolclass.LOCAL_TYPE_UNKNOWN
+        _email1=False
         for _entry in entry.get('emails', []):
             req.index=_entry['speeddial']
             if req.index>self.protocolclass.PB_TOTAL_ENTRIES:
                 continue
             req.number=_entry['email']
+            if _email1:
+                # this is email2
+                req.number_type=self.protocolclass.NUMBER_TYPE_EMAIL2
+            else:
+                _email1=True
             self._set_pb_entry_misc(req, _entry, fundamentals)
             self._del_pb_entry(req.index)
             self.sendATcommand(req, None)
@@ -347,13 +369,16 @@ class Phone(com_moto_cdma.Phone):
         _req.name=nameparser.getfullname(entry['names'][0])
         _req.group=self._get_group_code(entry, fundamentals)
         fundamentals['primary']=False
+        fundamentals['phonewallpaper']=entry.get('wallpapers', [{}])[0].get('wallpaper', None)
+        fundamentals['phoneringtone']=entry.get('ringtones', [{}])[0].get('ringtone', None)
         # first, write out the numbers
         self._write_pb_entry_numbers(entry, _req, fundamentals)
         # then email
         self._write_pb_entry_emails(entry, _req, fundamentals)
         # and mail list
         # self._write_pb_entry_maillist(entry, _req, fundamentals)
-        del fundamentals['primary']
+        del fundamentals['primary'], fundamentals['phonewallpaper'],
+        fundamentals['phoneringtone']
 
     def _write_pb_entries(self, fundamentals):
         """Write out the phonebook to the phone"""
@@ -692,10 +717,7 @@ class Profile(parentprofile):
         ('ringtone', 'write', 'OVERWRITE'),
         ('wallpaper', 'read', None),  # all wallpaper reading
         ('wallpaper', 'write', 'OVERWRITE'),
-##        ('memo', 'read', None),     # all memo list reading DJP
-##        ('memo', 'write', 'OVERWRITE'),  # all memo list writing DJP
         ('sms', 'read', None),     # all SMS list reading DJP
-##        ('call_history', 'read', None),
         )
 
     def convertphonebooktophone(self, helper, data):
@@ -733,8 +755,8 @@ class Profile(parentprofile):
             'url': 0,
             'memo': 0,
             'category': 1,
-            'wallpaper': 0,
-            'ringtone': 0,
+            'wallpaper': 1,
+            'ringtone': 1,
             'storage': 0,
             },
         'calendar': {
