@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_phone.py 3927 2007-01-22 03:15:22Z rogerb $
+### $Id: com_phone.py 4543 2008-01-04 23:44:24Z djpham $
 
 
 """Generic phone stuff that all models inherit from"""
@@ -180,11 +180,13 @@ class Profile(object):
     _supportedsyncs=(
         )
 
-    def SyncQuery(self, source, action, type):
-        if (source, action, type) in self._supportedsyncs or \
-           (source, action, None) in self._supportedsyncs:
-            return True
-        return False
+    def SyncQuery(self, source, action, actiontype):
+        if actiontype=='EXCLUSIVE':
+            # Check for exclusive, shoud not be masked by None
+            return (source, action, actiontype) in self._supportedsyncs
+        else:
+            return (source, action, actiontype) in self._supportedsyncs or \
+                   (source, action, None) in self._supportedsyncs
 
     # fill in the list of ringtone/sound origins on your phone
     ringtoneorigins=()
@@ -195,7 +197,7 @@ class Profile(object):
     excluded_ringtone_origins=()
 
     # wallpaper origins that are not available for the contact assignment
-    excluded_wallpaper_origins=('video')
+    excluded_wallpaper_origins=('video',)
 
     # fill in your own image origins using these
     stockimageorigins={
