@@ -5,7 +5,7 @@
 ### This program is free software; you can redistribute it and/or modify
 ### it under the terms of the BitPim license as detailed in the LICENSE file.
 ###
-### $Id: com_samsungscha950.py 4365 2007-08-17 21:11:59Z djpham $
+### $Id: com_samsungscha950.py 4567 2008-01-14 02:59:46Z djpham $
 
 """Communicate with the Samsung SCH-A950 Phone"""
 
@@ -84,6 +84,8 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         "Calls all the constructors and sets initial modes"
         com_phone.Phone.__init__(self, logtarget, commport)
 	com_brew.BrewProtocol.__init__(self)
+	self.pbentryclass=PBEntry
+	self.calendarclass=CalendarEntry
 	# born to be in BREW mode!
         self.mode=self.MODEBREW
 
@@ -501,7 +503,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             _cal_file_name='%s%04d'%(self.protocolclass.CAL_FILE_NAME_PREFIX,
                                      _cal_index.events[_cnt].index)
             _buf=prototypes.buffer(self.getfilecontents(_cal_file_name))
-            _bpcal=CalendarEntry(self, _buf, fundamentals).getvalue()
+            _bpcal=self.calendarclass(self, _buf, fundamentals).getvalue()
             _res[_bpcal.id]=_bpcal
         fundamentals['calendar']=_res
         return fundamentals
@@ -528,7 +530,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 # enough events already!
                 break
             try:
-                _cal_entry=CalendarEntry(self, _entry, fundamentals)
+                _cal_entry=self.calendarclass(self, _entry, fundamentals)
                 _buf=prototypes.buffer()
                 _cal_entry.writetobuffer(_buf)
                 _cal_file_name='%s%04d'%(self.protocolclass.CAL_FILE_NAME_PREFIX,
@@ -733,7 +735,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 if _len.itemlen:
                     _entry=self.protocolclass.PBEntry()
                     _entry.readfrombuffer(_buf)
-                    _pbentry=PBEntry(self, _entry, fundamentals).getvalue()
+                    _pbentry=self.pbentryclass(self, _entry, fundamentals).getvalue()
                     res[len(res)]=_pbentry
         except:
             self.log('Failed to read file: %s'%filename)
@@ -763,7 +765,8 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
         for _,_entry in wp_index.items():
             if _entry.get('name', None)==wp:
                 return _entry.get('filename', None)
-    def _rescale_and_cache(self, wp, filename,
+
+    def _rescale_and_cache(self, wp, filename, idx,
                            fundamentals):
         # rescale the wp and add it to the cache dir
         try:
@@ -785,7 +788,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 self.log('Failed to add cache image: '+wp)
                 raise
 
-    def _add_wp_cache(self, wp, fundamentals):
+    def _add_wp_cache(self, wp, idx, fundamentals):
         # check to see if it already exists
         _wp_range=fundamentals.get('wallpaper-range', {})
         if _wp_range.has_key(wp):
@@ -799,7 +802,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             # couldn't find the filename
             return
         # copy the image file, rescale, and put it in the cache dir
-        _newfilename=self._rescale_and_cache(wp, _filename, fundamentals)
+        _newfilename=self._rescale_and_cache(wp, _filename, idx, fundamentals)
         if _newfilename:
             # rescale successful, update the dict
             _wp_range[wp]='/ff/'+_newfilename
@@ -825,16 +828,16 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
             return fundamentals
         _req=self.protocolclass.ss_pb_write_req()
         _total_cnt=len(_pb_list)
-        _cnt=0
+        _cnt=1
         for _name,_key in _pb_list:
             try:
                 _entry=_pb_dict[_key]
                 # set up all the picture ID (wallpaper) images
                 _wp=_entry.get('wallpapers', [{}])[0].get('wallpaper', None)
                 if _wp:
-                    self._add_wp_cache(_wp, fundamentals)
+                    self._add_wp_cache(_wp, _cnt, fundamentals)
                 # setting up a new contact to send over
-                _pbentry=PBEntry(self, _entry, fundamentals)
+                _pbentry=self.pbentryclass(self, _entry, fundamentals)
                 _req.entry=_pbentry.pb
                 _cnt+=1
                 self.progress(_cnt, _total_cnt,
@@ -874,8 +877,7 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
                 _buf=prototypes.buffer(self.getfilecontents(
                     '%s%02d'%(self.protocolclass.CL_PREFIX, _idx)))
                 _req.readfrombuffer(_buf, 'Reading Call Log File')
-                if _req.cl_type in self.protocolclass.CL_VALID_TYPE and \
-                   _req.number:
+                if _req.valid:
                     _entry=call_history.CallHistoryEntry()
                     _entry.folder=folder
                     _entry.number=_req.number
@@ -976,13 +978,13 @@ class Phone(com_phone.Phone, com_brew.BrewProtocol):
 
     def getsms(self, fundamentals):
         res={}
-        try:
-            for _filename in self.listfiles(self.protocolclass.SMS_PATH):
+        for _filename in self.listfiles(self.protocolclass.SMS_PATH):
+            try:
                 self._read_sms(_filename, res, fundamentals)
-        except:
-            self.log('Failed to read SMS File '+_filename)
-            if __debug__:
-                raise
+            except:
+                self.log('Failed to read SMS File '+_filename)
+                if __debug__:
+                    raise
         fundamentals['sms']=res
         fundamentals['canned_msg']=[]
         return fundamentals
@@ -1137,7 +1139,7 @@ class CalendarEntry(object):
             return None
         _rep=bpcalendar.RepeatEntry(_rep_type)
         if _rep_type==_rep.daily:
-            _rep.inteval=1
+            _rep.interval=1
         elif _rep_type==_rep.weekly:
             _rep.interval=1
         elif _rep_type==_rep.monthly:
